"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.convertPrimaryColorsToString = exports.rgbToHsl = exports.sleep = exports.logger = exports.resetQuizSessionStorageState = exports.getStateFromSessionStorage = exports.isFunction = exports.getPreferredColorScheme = exports.getQuestionTypes = exports.stringify = exports.stringifyWithDefaults = exports.functionStrings = exports.getStoryParams = exports.renderImages = void 0;
const tslib_1 = require("tslib");
/* eslint-disable no-console */
const react_1 = tslib_1.__importDefault(require("react"));
const actions_1 = require("./components/CioQuiz/actions");
const renderImages = (images, cssClasses) => {
    const { primary_url: primaryUrl, primary_alt: primaryAlt, secondary_url: secondaryUrl, secondary_alt: secondaryAlt, } = images;
    if (primaryUrl) {
        const windowWidth = window.innerWidth;
        let src = primaryUrl;
        let alt = primaryAlt || 'Quiz Image';
        if (windowWidth > 768 && secondaryUrl) {
            src = secondaryUrl;
            if (secondaryAlt) {
                alt = secondaryAlt;
            }
        }
        return (react_1.default.createElement("span", { className: `${cssClasses || ''}`.trim() },
            react_1.default.createElement("img", { className: 'cio-question-image', src: src, alt: alt })));
    }
    return '';
};
exports.renderImages = renderImages;
// More on Story layout: https://storybook.js.org/docs/react/configure/story-layout
const getStoryParams = (storyCode, templateCode, importCode) => {
    const code = `
${importCode}
${storyCode}
${templateCode}
`;
    return {
        docs: {
            source: {
                code,
                language: 'jsx',
                format: true,
                type: 'code',
            },
        },
    };
};
exports.getStoryParams = getStoryParams;
exports.functionStrings = {
    onAddToCartClick: `(item) => console.dir(item)`,
    onQuizResultClick: `(result, position) => console.dir(result, position)`,
    onQuizResultsLoaded: `(results) => console.dir(results)`,
    cioJsClient: `cioJsClient`,
};
const stringifyWithDefaults = (obj) => {
    // Stringify non-function values normally. Add a template block for functions to be replaced later
    const customJsonTransformer = (key, value) => {
        if (value instanceof Function) {
            return `${key}_CODE`;
        }
        if (key === 'cioJsClient') {
            return `${key}_CODE`;
        }
        return value;
    };
    let res = JSON.stringify(obj, customJsonTransformer, '  ');
    // Replace template blocks with function strings
    Array.from(res.matchAll(/"(\w*)_CODE"/g)).forEach((match) => {
        const [codePlaceholder, key] = match;
        const functionString = exports.functionStrings[key];
        if (functionString) {
            res = res.replaceAll(codePlaceholder, functionString);
        }
        else {
            console.error(`Function string for ${key} not found.`); // eslint-disable-line
        }
    });
    return res;
};
exports.stringifyWithDefaults = stringifyWithDefaults;
const stringify = (obj) => JSON.stringify(obj, null, '  ');
exports.stringify = stringify;
const getQuestionTypes = (questionType) => {
    const isOpenQuestion = questionType === actions_1.QuestionTypes.OpenText;
    const isCoverQuestion = questionType === actions_1.QuestionTypes.Cover;
    const isSingleQuestion = questionType === actions_1.QuestionTypes.SingleSelect;
    const isMultipleQuestion = questionType === actions_1.QuestionTypes.MultipleSelect;
    const isSelectQuestion = isSingleQuestion || isMultipleQuestion;
    return {
        isOpenQuestion,
        isCoverQuestion,
        isSingleQuestion,
        isMultipleQuestion,
        isSelectQuestion,
    };
};
exports.getQuestionTypes = getQuestionTypes;
function getPreferredColorScheme() {
    var _a;
    let colorScheme = 'light';
    // Check if the dark-mode Media-Query matches
    if ((_a = window.matchMedia('(prefers-color-scheme: dark)')) === null || _a === void 0 ? void 0 : _a.matches) {
        colorScheme = 'dark';
    }
    return colorScheme;
}
exports.getPreferredColorScheme = getPreferredColorScheme;
function isFunction(fn) {
    return fn && typeof fn === 'function';
}
exports.isFunction = isFunction;
const getStateFromSessionStorage = (quizStateKey) => {
    var _a;
    const state = (_a = window === null || window === void 0 ? void 0 : window.sessionStorage) === null || _a === void 0 ? void 0 : _a.getItem(quizStateKey);
    if (state) {
        return JSON.parse(state);
    }
    return null;
};
exports.getStateFromSessionStorage = getStateFromSessionStorage;
const resetQuizSessionStorageState = (quizStateKey) => () => {
    var _a;
    (_a = window === null || window === void 0 ? void 0 : window.sessionStorage) === null || _a === void 0 ? void 0 : _a.removeItem(quizStateKey);
};
exports.resetQuizSessionStorageState = resetQuizSessionStorageState;
const logger = (action) => {
    console.group(`%cAction:%c  ${action.type}`, 'color: red; font-weight: bold;', 'color: green; font-weight: lighter;');
    console.log('%c type:', 'color: #9E9E9E; font-weight: 700;', action.type);
    console.log('%c payload:', 'color: #00A7F7; font-weight: 700;', action.payload);
    console.groupEnd();
};
exports.logger = logger;
// Function to emulate pausing between interactions
function sleep(ms) {
    // eslint-disable-next-line
    return new Promise((resolve) => setTimeout(resolve, ms));
}
exports.sleep = sleep;
function rgbToHsl(r, g, b) {
    const rConverted = r / 255;
    const gConverted = g / 255;
    const bConverted = b / 255;
    const max = Math.max(rConverted, gConverted, bConverted);
    const min = Math.min(rConverted, gConverted, bConverted);
    const delta = max - min;
    let h = 0;
    if (delta === 0)
        h = 0;
    else if (max === rConverted)
        h = ((gConverted - bConverted) / delta) % 6;
    else if (max === gConverted)
        h = (bConverted - rConverted) / delta + 2;
    else if (max === bConverted)
        h = (rConverted - gConverted) / delta + 4;
    const l = (min + max) / 2;
    const s = delta === 0 ? 0 : delta / (1 - Math.abs(2 * l - 1));
    const finalH = Math.round(h * 60);
    const finalS = Math.round(s * 100);
    const finalL = Math.round(l * 100);
    return [finalH, finalS, finalL];
}
exports.rgbToHsl = rgbToHsl;
function convertPrimaryColorsToString(primaryColorStyles) {
    return `{
    --primary-color-h: ${primaryColorStyles['--primary-color-h']}; 
    --primary-color-s: ${primaryColorStyles['--primary-color-s']}; 
    --primary-color-l: ${primaryColorStyles['--primary-color-l']}; 
  }`;
}
exports.convertPrimaryColorsToString = convertPrimaryColorsToString;
