/* eslint-disable @typescript-eslint/naming-convention */
import ConstructorIOClient from '@constructor-io/constructorio-client-javascript';
export const getCioClient = (apiKey) => {
    if (apiKey) {
        return new ConstructorIOClient({
            apiKey,
            sendTrackingEvents: true,
        });
    }
    return undefined;
};
export const getNextQuestion = (cioClient, quizId, parameters) => cioClient?.quizzes.getQuizNextQuestion(quizId, parameters);
export const getQuizResults = async (cioClient, quizId, parameters) => cioClient?.quizzes.getQuizResults(quizId, parameters);
// Tracking requests
export const trackQuizResultsLoaded = (cioClient, quizResults) => {
    const { quiz_id, quiz_session_id, quiz_version_id, result_id, request, response } = quizResults;
    cioClient?.tracker.trackQuizResultsLoaded({
        quizId: quiz_id,
        quizVersionId: quiz_version_id,
        quizSessionId: quiz_session_id,
        url: window.location.href,
        section: request?.section,
        resultCount: response?.total_num_results,
        resultPage: request?.page,
        resultId: result_id,
    });
};
export const trackQuizResultClick = (cioClient, quizResults, result, position) => {
    if (quizResults.request && quizResults.response) {
        const { quiz_id, quiz_session_id, quiz_version_id, result_id, request: { section, page, num_results_per_page }, response: { total_num_results }, } = quizResults;
        cioClient?.tracker.trackQuizResultClick({
            quizId: quiz_id,
            quizVersionId: quiz_version_id,
            quizSessionId: quiz_session_id,
            itemId: result.data?.id,
            itemName: result?.value,
            section,
            resultCount: total_num_results,
            resultPage: page,
            resultId: result_id,
            resultPositionOnPage: position,
            numResultsPerPage: num_results_per_page,
        });
    }
};
export const trackQuizConversion = (cioClient, quizResults, result, price) => {
    if (quizResults.request) {
        const { quiz_id, quiz_session_id, quiz_version_id, request: { section }, } = quizResults;
        cioClient?.tracker.trackQuizConversion({
            quizId: quiz_id,
            quizVersionId: quiz_version_id,
            quizSessionId: quiz_session_id,
            itemId: result.data?.id,
            itemName: result.value,
            section,
            variationId: result.data?.variation_id,
            revenue: (price && String(price)) || undefined,
        });
    }
};
