/// <reference types="react" />
import { QuizResultData, NextQuestionResponse, QuizResultsResponse, Nullable, QuestionOption } from '@constructor-io/constructorio-client-javascript/lib/types';
import ConstructorIOClient from '@constructor-io/constructorio-client-javascript';
import { RequestStates } from './constants';
import { QuestionTypes } from './components/CioQuiz/actions';
export type { QuestionOption, QuestionImages, Question, NextQuestionResponse, QuizResultsResponse, BrowseResultData, BrowseRequestType, QuizzesParameters, QuizzesResultsParameters, } from '@constructor-io/constructorio-client-javascript/lib/types';
export type QuizResultDataPartial = Partial<QuizResultData>;
export interface ResultCardProps {
    resultCardSalePriceKey?: string;
    resultCardRegularPriceKey?: string;
    resultCardRatingCountKey?: string;
    resultCardRatingScoreKey?: string;
    renderResultCardPriceDetails?: (result: QuizResultDataPartial) => JSX.Element;
}
export declare namespace QuizResultsEventsProps {
    type OnQuizResultsLoaded = (results: QuizResultDataPartial) => void;
    type OnQuizResultClick = (result: QuizResultDataPartial, position: number) => void;
    type OnAddToCartClick = (result: QuizResultDataPartial) => void;
}
export interface ResultsPageOptions extends ResultCardProps {
    numResultsToDisplay?: number;
    onQuizResultsLoaded?: QuizResultsEventsProps.OnQuizResultsLoaded;
    onQuizResultClick?: QuizResultsEventsProps.OnQuizResultClick;
    onAddToCartClick: QuizResultsEventsProps.OnAddToCartClick;
}
export interface SessionStateOptions {
    showSessionModal?: boolean;
    showSessionModalOnResults?: boolean;
    sessionStateKey?: string;
}
export interface IQuizProps {
    apiKey?: string;
    cioJsClient?: ConstructorIOClient;
    quizId: string;
    quizVersionId?: string;
    resultsPageOptions: ResultsPageOptions;
    sessionStateOptions?: SessionStateOptions;
    primaryColor?: string;
}
export interface QuizReturnState {
    answers: {
        inputs: AnswerInputState;
        isLastAnswer: boolean;
    };
    quiz: {
        requestState: RequestStates;
        versionId?: string;
        sessionId?: string;
        currentQuestion?: CurrentQuestion | undefined;
        results?: QuizResultsResponse | undefined;
        skipToResults: boolean;
        selectedOptionsWithAttributes?: string[];
    };
}
export type AnswerInputState = {
    [key: string]: {
        type: InputQuestionsTypes;
        value: string | string[];
    };
};
export type InputQuestionsTypes = QuestionTypes.OpenText | QuestionTypes.Cover | QuestionTypes.SingleSelect | QuestionTypes.MultipleSelect;
export type CurrentQuestion = NextQuestionResponse & {
    isFirstQuestion: boolean;
    isOpenQuestion: boolean;
    isCoverQuestion: boolean;
    isSingleQuestion: boolean;
    isMultipleQuestion: boolean;
    isSelectQuestion: boolean;
};
export declare namespace QuizEventsReturn {
    type QuizAnswerChanged = (payload?: string | string[]) => void;
    type NextQuestion = () => void;
    type PreviousQuestion = () => void;
    type ResetQuiz = () => void;
    type ResultClick = (result: QuizResultDataPartial, position: number) => void;
    type AddToCart = (e: React.MouseEvent<HTMLElement>, result: QuizResultDataPartial, price?: number) => void;
    type HydrateQuiz = () => void;
    type HasSessionStorageState = () => boolean;
    type ResetSessionStorageState = () => void;
}
export interface QuizEventsReturn {
    nextQuestion: QuizEventsReturn.NextQuestion;
    quizAnswerChanged: QuizEventsReturn.QuizAnswerChanged;
    previousQuestion: QuizEventsReturn.PreviousQuestion;
    resetQuiz: QuizEventsReturn.ResetQuiz;
    resultClick: QuizEventsReturn.ResultClick;
    addToCart: QuizEventsReturn.AddToCart;
    hydrateQuiz: QuizEventsReturn.HydrateQuiz;
    hasSessionStorageState: QuizEventsReturn.HasSessionStorageState;
    resetSessionStorageState: QuizEventsReturn.ResetSessionStorageState;
}
export interface OpenTextInputProps {
    className: string;
    placeholder: string;
    value: string;
    onChange: React.ChangeEventHandler<HTMLInputElement>;
    onKeyDown: React.KeyboardEventHandler<HTMLInputElement>;
}
export interface CoverQuestionProps {
}
export interface NextQuestionButtonProps {
    className: string;
    type: 'submit' | 'reset' | 'button' | undefined;
    disabled?: boolean;
    onClick: React.MouseEventHandler<HTMLElement>;
}
export interface PreviousQuestionButtonProps {
    className: string;
    type: 'submit' | 'reset' | 'button' | undefined;
    onClick: React.MouseEventHandler<HTMLElement>;
    style?: Record<string, string>;
}
export interface ResetQuizButtonProps {
    className: string;
    type: 'submit' | 'reset' | 'button' | undefined;
    onClick: React.MouseEventHandler<HTMLElement>;
    style?: Record<string, string>;
}
export interface HydrateQuizButtonProps {
    className: string;
    type: 'submit' | 'reset' | 'button' | undefined;
    onClick: React.MouseEventHandler<HTMLElement>;
    style?: Record<string, string>;
}
export interface AddToCartButtonProps {
    className: string;
    type: 'submit' | 'reset' | 'button' | undefined;
    onClick: React.MouseEventHandler<HTMLElement>;
    style?: Record<string, string>;
}
export interface QuizImageProps {
    className?: string;
    src?: Nullable<string>;
    alt?: Nullable<string>;
}
export interface QuizResultPropsLink {
    href?: string;
    onClick: React.MouseEventHandler<HTMLElement>;
    onKeyDown: React.KeyboardEventHandler<HTMLElement>;
}
export interface QuizResultPropsButton {
    className: string;
    role: 'button';
    tabIndex: number;
    onClick: React.MouseEventHandler<HTMLElement>;
    onKeyDown: React.KeyboardEventHandler<HTMLElement>;
}
export type QuizResultProps = QuizResultPropsLink | QuizResultPropsButton;
export interface SelectInputProps {
    className: string;
    onClick: React.MouseEventHandler<HTMLElement>;
    onKeyDown: React.KeyboardEventHandler<HTMLElement>;
    role: 'button';
    tabIndex: number;
    key: number;
}
export type GetOpenTextInputProps = () => OpenTextInputProps;
export type GetCoverQuestionProps = () => CoverQuestionProps;
export type GetSelectInputProps = (option: QuestionOption) => SelectInputProps;
export type GetNextQuestionButtonProps = () => NextQuestionButtonProps;
export type GetPreviousQuestionButtonProps = () => PreviousQuestionButtonProps;
export type GetResetQuizButtonProps = (stylesType?: 'primary' | 'secondary') => ResetQuizButtonProps;
export type GetHydrateQuizButtonProps = () => HydrateQuizButtonProps;
export type GetAddToCartButtonProps = (result: QuizResultDataPartial, price?: number) => AddToCartButtonProps;
export type GetQuizImageProps = () => QuizImageProps;
export type GetSelectQuestionImageProps = (option: QuestionOption) => QuizImageProps;
export interface QuizResultOptions<T = 'button' | 'link'> {
    result: QuizResultDataPartial;
    position: number;
    type?: T;
}
export type GetQuizResultButtonProps = (options: QuizResultOptions<'button'>) => QuizResultPropsButton;
export type GetQuizResultLinkProps = (options: QuizResultOptions<'link'>) => QuizResultPropsLink;
export interface PrimaryColorStyles {
    '--primary-color-h': string;
    '--primary-color-s': string;
    '--primary-color-l': string;
}
export interface UseQuizReturn {
    cioClient?: ConstructorIOClient;
    state: QuizReturnState;
    events: QuizEventsReturn;
    getOpenTextInputProps: GetOpenTextInputProps;
    getNextQuestionButtonProps: GetNextQuestionButtonProps;
    getPreviousQuestionButtonProps: GetPreviousQuestionButtonProps;
    getQuizImageProps: GetQuizImageProps;
    getSelectQuestionImageProps: GetSelectQuestionImageProps;
    getSelectInputProps: GetSelectInputProps;
    getCoverQuestionProps: GetCoverQuestionProps;
    getResetQuizButtonProps: GetResetQuizButtonProps;
    getHydrateQuizButtonProps: GetHydrateQuizButtonProps;
    getAddToCartButtonProps: GetAddToCartButtonProps;
    getQuizResultButtonProps: GetQuizResultButtonProps;
    getQuizResultLinkProps: GetQuizResultLinkProps;
    primaryColorStyles: PrimaryColorStyles;
}
export type UseQuiz = (quizProps: IQuizProps) => UseQuizReturn;
